@@ -145,24 +145,24 @@ class RelyComplyCLI:
         kwargs = {}
 
         for key, value in raw_kwargs.items():
-            if key.startswith("@"):
-                # This is a file reference we load the file and maybe base64 encode it
-                new_key = key[1:]
-                if self.is_base64_field(set_args.type, set_args.action, new_key):
-                    with open(value, "rb") as f:
-                        new_value = b64encode(f.read()).decode("ascii")
-                else:
-                    with open(value, "r") as f:
-                        new_value = f.read()
+            # if key.startswith("@"):
+            #     # This is a file reference we load the file and maybe base64 encode it
+            #     new_key = key[1:]
+            #     if self.is_base64_field(set_args.type, set_args.action, new_key):
+            #         with open(value, "rb") as f:
+            #             new_value = b64encode(f.read()).decode("ascii")
+            #     else:
+            #         with open(value, "r") as f:
+            #             new_value = f.read()
 
-                kwargs[new_key] = new_value
-            else:
-                # We check if the value is json encoded, and decode it, otherwise it is just a string
-                try:
-                    value = json.loads(value)
-                    kwargs[key] = value
-                except JSONDecodeError as e:
-                    kwargs[key] = value
+            #     kwargs[new_key] = new_value
+            # else:
+            # We check if the value is json encoded, and decode it, otherwise it is just a string
+            try:
+                value = json.loads(value)
+                kwargs[key] = value
+            except JSONDecodeError as e:
+                kwargs[key] = value
 
         straight_args = [part for part in other_args if not part.startswith("--")]
 
@@ -200,7 +200,33 @@ class RelyComplyCLI:
             variables=variables,
         )
 
+    def enrich_variables(self, type, action, variables):
+        def enrich_pair(k, v):
+            if k.startswith("@"):
+                new_key = k[1:]
+                if self.is_base64_field(type, action, new_key):
+                    with open(v, "rb") as f:
+                        new_value = b64encode(f.read()).decode("ascii")
+                else:
+                    with open(v, "r") as f:
+                        new_value = f.read()
+
+                return new_key, new_value
+            else:
+                return k, v
+
+        def visit(root):
+            if isinstance(root, list):
+                return [visit(child) for child in root]
+            elif isinstance(root, dict):
+                return dict(enrich_pair(k, v) for k, v in root.items())
+            else:
+                return root
+
+        return visit(variables)
+
     def execute(self, type, action, variables):
+        variables = self.enrich_variables(type, action, variables)
         field_type, field = self.get_graphql_field(type, action)
         if field_type == "mutation":
             return self.gql.execute_mutation(field, variables)
